Google Music Player
===================

A GTK music player based on google music API

INSTALL
-------
.. code::
   
    apt-get install python-gtk virtualenv vlc
    virtualenv venv --system-site-packages
    source venv/bin/activate
    pip install -U setuptools
    python setup.py install
    run
    enjoy! ;)
